@@ -1,7 +1,4 @@
 /***************************************************************************
- $RCSfile$
- -------------------
- cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -42,6 +39,18 @@ extern "C" {
  */
 /*@{*/
 
+/**
+ * Returns a list of currently known users, or NULL if there are no
+ * users. The returned list is owned by the caller, so he is
+ * responsible for freeing it (using @ref AB_User_List2_free).
+ *
+ * Please note that even while the list is owned by the caller the users
+ * in that list are not! So you may not free any of those users in the
+ * list (e.g. by calling @ref AB_User_List2_FreeAll).
+ *
+ * @return The list of users, or NULL if there are none.
+ * @param ab pointer to the AB_BANKING object
+ */
 AQBANKING_API
 AB_USER_LIST2 *AB_Banking_GetUsers(const AB_BANKING *ab);
 
@@ -231,7 +240,8 @@ AB_ACCOUNT *AB_Banking_FindAccount(const AB_BANKING *ab,
                                    const char *backendName,
                                    const char *country,
                                    const char *bankId,
-                                   const char *accountId);
+                                   const char *accountId,
+                                   const char *subAccountId);
 
 /**
  * This function returns a list of accounts which match the given
@@ -249,7 +259,8 @@ AB_ACCOUNT_LIST2 *AB_Banking_FindAccounts(const AB_BANKING *ab,
                                           const char *backendName,
                                           const char *country,
                                           const char *bankId,
-                                          const char *accountId);
+                                          const char *accountId,
+                                          const char *subAccountId);
 
 /**
  * Creates an account and shows it to the backend (which might want to extend
@@ -307,8 +318,7 @@ int AB_Banking_DeleteAccount(AB_BANKING *ab, AB_ACCOUNT *a);
  */
 AQBANKING_API 
 int AB_Banking_ExecuteJobs(AB_BANKING *ab, AB_JOB_LIST2 *jl2,
-			   AB_IMEXPORTER_CONTEXT *ctx,
-			   uint32_t guiid);
+			   AB_IMEXPORTER_CONTEXT *ctx);
 /*@}*/
 
 
