@@ -1,13 +1,14 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: jobeutransfer_p.h 764 2006-01-13 14:00:00Z cstim $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
- *          Please see toplevel file COPYING for license details           *
+ * This file is part of the project "AqBanking".                           *
+ * Please see toplevel file COPYING of that project for license details.   *
  ***************************************************************************/
 
 
@@ -26,7 +27,7 @@ struct AB_JOBEUTRANSFER {
   int ibanAllowed;
   AB_JOBEUTRANSFER_CHARGE_WHOM chargeWhom;
 };
-static void AB_JobEuTransfer_FreeData(void *bp, void *p);
+static void GWENHYWFAR_CB AB_JobEuTransfer_FreeData(void *bp, void *p);
 
 
 #endif
