@@ -1,13 +1,14 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: transactionfns.h 705 2005-12-01 12:46:15Z cstim $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
- *          Please see toplevel file COPYING for license details           *
+ * This file is part of the project "AqBanking".                           *
+ * Please see toplevel file COPYING of that project for license details.   *
  ***************************************************************************/
 
 
@@ -16,6 +17,7 @@
 #define AQBANKING_TRANSACTIONFNS_H
 
 #include <aqbanking/transaction.h>
+#include <aqbanking/account.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -29,6 +31,14 @@ AQBANKING_API
 int AB_Transaction_Compare(const AB_TRANSACTION *t1,
                            const AB_TRANSACTION *t0);
 
+/**
+ * Fills "local account" parts of the given transaction with the data
+ * from the given account. In particular, the following fields are set
+ * through this function: SetLocalCountry, SetRemoteCountry,
+ * SetLocalBankCode, SetLocalAccountNumber, and SetLocalName.
+ */
+AQBANKING_API
+void AB_Transaction_FillLocalFromAccount(AB_TRANSACTION *t, const AB_ACCOUNT *a);
 
 
 #ifdef __cplusplus
