@@ -134,6 +134,13 @@ static int createTanMethodString(const AH_TAN_METHOD *tm, GWEN_BUFFER *tbuf) {
     GWEN_Buffer_AppendString(tbuf, s);
   }
 
+  /* add HKTAN version */
+  GWEN_Buffer_AppendString(tbuf, " (Version ");
+  snprintf(numbuf, sizeof(numbuf)-1, "%d", AH_TanMethod_GetGvVersion(tm));
+  numbuf[sizeof(numbuf)-1]=0;
+  GWEN_Buffer_AppendString(tbuf, numbuf);
+  GWEN_Buffer_AppendString(tbuf, ")");
+
   return 0;
 }
 
@@ -196,7 +203,7 @@ const AH_TAN_METHOD *AH_EditUserPinTanDialog_GetCurrentTanMethod(GWEN_DIALOG *dl
     const char *currentText;
 
     currentText=GWEN_Dialog_GetCharProperty(dlg, "tanMethodCombo", GWEN_DialogProperty_Value, idx, NULL);
-    if (currentText && *currentText && xdlg->countryList) {
+    if (currentText && *currentText && xdlg->tanMethodList) {
       AH_TAN_METHOD *tm;
       GWEN_BUFFER *tbuf;
 
@@ -246,15 +253,19 @@ static void AH_EditUserPinTanDialog_UpdateTanMethods(GWEN_DIALOG *dlg) {
     int i;
     int idx;
     int selectedMethod;
+    int tjv;
+    int tfn;
 
     selectedMethod=AH_User_GetSelectedTanMethod(xdlg->user);
+    tjv=selectedMethod / 1000;
+    tfn=selectedMethod % 1000;
     tbuf=GWEN_Buffer_new(0, 256, 0, 1);
     idx=-1;
     i=1;
     tm=AH_TanMethod_List_First(xdlg->tanMethodList);
     while(tm) {
       if (createTanMethodString(tm, tbuf)==0) {
-	if (AH_TanMethod_GetFunction(tm)==selectedMethod)
+	if (AH_TanMethod_GetFunction(tm)==tfn && AH_TanMethod_GetGvVersion(tm)==tjv)
           idx=i;
 	GWEN_Dialog_SetCharProperty(dlg, "tanMethodCombo", GWEN_DialogProperty_AddValue, 0, GWEN_Buffer_GetStart(tbuf), 0);
         i++;
@@ -278,6 +289,7 @@ void AH_EditUserPinTanDialog_Init(GWEN_DIALOG *dlg) {
   int i;
   const char *s;
   uint32_t flags;
+  const GWEN_URL *gu;
 
   assert(dlg);
   xdlg=GWEN_INHERIT_GETDATA(GWEN_DIALOG, AH_EDIT_USER_PINTAN_DIALOG, dlg);
@@ -357,6 +369,7 @@ void AH_EditUserPinTanDialog_Init(GWEN_DIALOG *dlg) {
       GWEN_Dialog_SetIntProperty(dlg, "countryCombo", GWEN_DialogProperty_Value, 0, idx, 0);
   }
 
+  /* also selects currently selected TAN method */
   AH_EditUserPinTanDialog_UpdateTanMethods(dlg);
 
   s=AB_User_GetUserName(xdlg->user);
@@ -365,6 +378,16 @@ void AH_EditUserPinTanDialog_Init(GWEN_DIALOG *dlg) {
   s=AB_User_GetBankCode(xdlg->user);
   GWEN_Dialog_SetCharProperty(dlg, "bankCodeEdit", GWEN_DialogProperty_Value, 0, s, 0);
 
+  gu=AH_User_GetServerUrl(xdlg->user);
+  if (gu) {
+    GWEN_BUFFER *tbuf;
+
+    tbuf=GWEN_Buffer_new(0, 256, 0, 1);
+    GWEN_Url_toString(gu, tbuf);
+    GWEN_Dialog_SetCharProperty(dlg, "urlEdit", GWEN_DialogProperty_Value, 0, GWEN_Buffer_GetStart(tbuf), 0);
+    GWEN_Buffer_free(tbuf);
+  }
+
   s=AB_User_GetUserId(xdlg->user);
   GWEN_Dialog_SetCharProperty(dlg, "userIdEdit", GWEN_DialogProperty_Value, 0, s, 0);
 
@@ -390,6 +413,14 @@ void AH_EditUserPinTanDialog_Init(GWEN_DIALOG *dlg) {
   default:  break;
   }
 
+  /* TAN medium id */
+  s=AH_User_GetTanMediumId(xdlg->user);
+  GWEN_Dialog_SetCharProperty(dlg, "tanMediumIdEdit", GWEN_DialogProperty_Value, 0, s, 0);
+  GWEN_Dialog_SetCharProperty(dlg, "tanMediumIdEdit", GWEN_DialogProperty_ToolTip, 0,
+                              I18N("For smsTAN or mTAN this is your mobile phone number. "
+                                   "Please ask your bank for the necessary format of this number."),
+                              0);
+
   flags=AH_User_GetFlags(xdlg->user);
   GWEN_Dialog_SetIntProperty(dlg, "forceSslv3Check", GWEN_DialogProperty_Value, 0,
 			     (flags & AH_USER_FLAGS_FORCE_SSL3)?1:0,
@@ -517,8 +548,48 @@ int AH_EditUserPinTanDialog_fromGui(GWEN_DIALOG *dlg, AB_USER *u, int quiet) {
   }
 
   tm=AH_EditUserPinTanDialog_GetCurrentTanMethod(dlg);
-  if (tm)
-    AH_User_SetSelectedTanMethod(xdlg->user, AH_TanMethod_GetFunction(tm));
+  if (tm) {
+    int fn;
+
+    fn=(AH_TanMethod_GetGvVersion(tm)*1000)+AH_TanMethod_GetFunction(tm);
+    AH_User_SetSelectedTanMethod(xdlg->user, fn);
+  }
+
+  /* handle tan medium id */
+  s=GWEN_Dialog_GetCharProperty(dlg, "tanMediumIdEdit", GWEN_DialogProperty_Value, 0, NULL);
+  if (s && *s) {
+    GWEN_BUFFER *tbuf;
+
+    tbuf=GWEN_Buffer_new(0, 256, 0, 1);
+    GWEN_Buffer_AppendString(tbuf, s);
+    GWEN_Text_CondenseBuffer(tbuf);
+    if (u)
+      AH_User_SetTanMediumId(u, GWEN_Buffer_GetStart(tbuf));
+    GWEN_Buffer_free(tbuf);
+  }
+
+  s=GWEN_Dialog_GetCharProperty(dlg, "urlEdit", GWEN_DialogProperty_Value, 0, NULL);
+  if (s && *s) {
+    GWEN_BUFFER *tbuf;
+    GWEN_URL *gu;
+
+    tbuf=GWEN_Buffer_new(0, 256, 0, 1);
+    GWEN_Buffer_AppendString(tbuf, s);
+    GWEN_Text_CondenseBuffer(tbuf);
+    removeAllSpaces((uint8_t*)GWEN_Buffer_GetStart(tbuf));
+    gu=GWEN_Url_fromString(GWEN_Buffer_GetStart(tbuf));
+    if (gu==NULL) {
+      if (!quiet) {
+	GWEN_Gui_ShowError(I18N("Error"), "%s", I18N("Invalid URL"));
+      }
+      GWEN_Buffer_free(tbuf);
+      return GWEN_ERROR_BAD_DATA;
+    }
+    if (u)
+      AH_User_SetServerUrl(u, gu);
+    GWEN_Url_free(gu);
+    GWEN_Buffer_free(tbuf);
+  }
 
   flags=0;
   if (GWEN_Dialog_GetIntProperty(dlg, "forceSslv3Check", GWEN_DialogProperty_Value, 0, 0))
