@@ -1570,11 +1570,14 @@ int AH_Job__CommitSystemData(AH_JOB *j, int doLock) {
                 j=GWEN_DB_GetIntValue(dbRes, "param", i, 0);
 		if (j==0)
 		  break;
+		DBG_NOTICE(AQHBCI_LOGDOMAIN, "Adding allowed TAN method %d", j);
 		AH_User_AddTanMethod(u, j);
 	      } /* for */
-	      if (i==0)
+	      if (i==0) {
                 /* add single step if empty list */
+		DBG_INFO(AQHBCI_LOGDOMAIN, "No allowed TAN method reported, assuming 999");
 		AH_User_AddTanMethod(u, 999);
+	      }
 	    }
           } /* if result */
           dbRes=GWEN_DB_GetNextGroup(dbRes);
@@ -1754,18 +1757,14 @@ int AH_Job__CommitSystemData(AH_JOB *j, int doLock) {
                      "Account \"%s\" already exists",
                      accountId);
 	  accCreated=0;
-	  if (doLock) {
-	    rv=AB_Banking_BeginExclUseAccount(ab, acc);
-	    if (rv<0) {
-	      DBG_ERROR(AQHBCI_LOGDOMAIN, "here (%d)", rv);
-	      mayModifyAcc=0;
-	    }
-	    else
-	      mayModifyAcc=1;
+	  rv=AB_Banking_BeginExclUseAccount(ab, acc);
+	  if (rv<0) {
+	    DBG_ERROR(AQHBCI_LOGDOMAIN, "here (%d)", rv);
+	    mayModifyAcc=0;
 	  }
-          else
+	  else
 	    mayModifyAcc=1;
-        }
+	}
         else {
           DBG_NOTICE(AQHBCI_LOGDOMAIN, "Creating account \"%s\"", accountId);
 	  accCreated=1;
@@ -1775,11 +1774,6 @@ int AH_Job__CommitSystemData(AH_JOB *j, int doLock) {
           AB_Account_SetCountry(acc, "de");
           AB_Account_SetBankCode(acc, bankCode);
 	  AB_Account_SetAccountNumber(acc, accountId);
-          if (strcasecmp(GWEN_DB_GroupName(dbRd), "AccountData2")==0)
-            /* KTV in version 2 available */
-            AH_Account_AddFlags(acc, AH_BANK_FLAGS_KTV2);
-          else
-            AH_Account_SubFlags(acc, AH_BANK_FLAGS_KTV2);
           DBG_NOTICE(AQHBCI_LOGDOMAIN,
                      "Setting user \"%s\" for account \"%s\"",
                      AB_User_GetUserId(u),
@@ -1799,6 +1793,22 @@ int AH_Job__CommitSystemData(AH_JOB *j, int doLock) {
           if (accountSuffix && *accountSuffix)
             AB_Account_SetSubAccountId(acc, accountSuffix);
 
+	  if (strcasecmp(GWEN_DB_GroupName(dbRd), "AccountData2")==0) {
+	    /* KTV in version 2 available */
+	    AH_Account_AddFlags(acc, AH_BANK_FLAGS_KTV2);
+	    DBG_NOTICE(AQHBCI_LOGDOMAIN, "Extended account information is available");
+	    GWEN_Gui_ProgressLog(0,
+				 GWEN_LoggerLevel_Notice,
+				 I18N("Extended account information available"));
+	  }
+	  else {
+	    AH_Account_SubFlags(acc, AH_BANK_FLAGS_KTV2);
+	    DBG_WARN(AQHBCI_LOGDOMAIN, "Extended account information is not available, some jobs might not work");
+	    GWEN_Gui_ProgressLog(0,
+				 GWEN_LoggerLevel_Warning,
+				 I18N("Extended account information is not available, some jobs might not work"));
+	  }
+
 	  /* set bank name */
 	  bpd=AH_User_GetBpd(j->user);
 	  if (bpd) {
@@ -1830,12 +1840,10 @@ int AH_Job__CommitSystemData(AH_JOB *j, int doLock) {
 	  AB_Banking_AddAccount(ab, acc);
 	else {
 	  if (mayModifyAcc) {
-	    if (doLock) {
-	      rv=AB_Banking_EndExclUseAccount(ab, acc, 0);
-	      if (rv<0) {
-		DBG_INFO(AQHBCI_LOGDOMAIN, "here (%d)", rv);
-		AB_Banking_EndExclUseAccount(ab, acc, 1); /* abort */
-	      }
+	    rv=AB_Banking_EndExclUseAccount(ab, acc, 0);
+	    if (rv<0) {
+	      DBG_INFO(AQHBCI_LOGDOMAIN, "here (%d)", rv);
+	      AB_Banking_EndExclUseAccount(ab, acc, 1); /* abort */
 	    }
 	  }
 	}
@@ -1862,6 +1870,7 @@ int AH_Job__CommitSystemData(AH_JOB *j, int doLock) {
 	  AB_Message_SetText(amsg, text);
 	  AB_Message_SetDateReceived(amsg, ti);
 	  GWEN_Time_free(ti);
+	  AB_Message_SetUserId(amsg, AB_User_GetUniqueId(u));
 	  AB_Message_List_Add(amsg, j->messages);
 
 	  if (1) {
