@@ -86,7 +86,7 @@ struct AH_JOB {
 static void AH_Job_SampleResults(AH_JOB *j);
 static AH_JOB *AH_Job__freeAll_cb(AH_JOB *j, void *userData);
 
-static int AH_Job__CommitSystemData(AH_JOB *j, int doLock, uint32_t guiid);
+static int AH_Job__CommitSystemData(AH_JOB *j, int doLock);
 
 
 #endif /* AH_JOB_P_H */
