@@ -20,9 +20,9 @@
 #include <aqbanking/provider_be.h>
 
 
-void AH_Account_Extend(AB_ACCOUNT *a, AB_PROVIDER *pro,
-		       AB_PROVIDER_EXTEND_MODE um,
-		       GWEN_DB_NODE *db);
+int AH_Account_Extend(AB_ACCOUNT *a, AB_PROVIDER *pro,
+                      AB_PROVIDER_EXTEND_MODE um,
+                      GWEN_DB_NODE *db);
 
 AH_HBCI *AH_Account_GetHbci(const AB_ACCOUNT *a);
 
