@@ -1,7 +1,4 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -63,6 +60,7 @@ struct AH_USER {
   char *prompt;
 
   AH_TAN_METHOD_LIST *tanMethodDescriptions;
+  char *tanMediumId;
 
   int maxTransfersPerJob;
   int maxDebitNotesPerJob;
