@@ -1,6 +1,4 @@
 /***************************************************************************
- $RCSfile$
- -------------------
  begin       : Wed Jan 09 2008
  copyright   : (C) 2008 by Martin Preuss
  email       : martin@libchipcard.de
@@ -53,8 +51,7 @@ int AO_Provider__AddHeaders(AB_PROVIDER *pro,
 
 int AO_Provider__AddSignOn(AB_PROVIDER *pro,
 			   AB_USER *u,
-			   GWEN_BUFFER *buf,
-			   uint32_t guiid) {
+			   GWEN_BUFFER *buf) {
   GWEN_TIME *ti;
   const char *s;
   char userpass[64];
@@ -79,7 +76,7 @@ int AO_Provider__AddSignOn(AB_PROVIDER *pro,
   else {
     DBG_ERROR(AQOFXCONNECT_LOGDOMAIN,
 	      "Missing user id, should not happen");
-    GWEN_Gui_ProgressLog(guiid,
+    GWEN_Gui_ProgressLog(0,
 			 GWEN_LoggerLevel_Error,
 			 I18N("Missing user id, should not happen"));
     return GWEN_ERROR_INTERNAL;
@@ -90,10 +87,10 @@ int AO_Provider__AddSignOn(AB_PROVIDER *pro,
   while (strlen(userpass)<4) {
     GWEN_BUFFER *nbuf;
     int rv;
-    char msg[]=I18N_NOOP("Please enter the password for user %s"
-			 "<html>"
-			 "Please enter the password for user <b>%s</b>"
-			 "</html>");
+    char msg[]=I18S("Please enter the password for user %s"
+                    "<html>"
+                    "Please enter the password for user <b>%s</b>"
+                    "</html>");
     char msgbuf[512];
 
     nbuf=GWEN_Buffer_new(0, 64, 0, 1);
@@ -106,8 +103,8 @@ int AO_Provider__AddSignOn(AB_PROVIDER *pro,
 			    msgbuf,
 			    userpass,
 			    4,
-                            sizeof(userpass),
-			    guiid);
+			    sizeof(userpass),
+			    0);
     GWEN_Buffer_free(nbuf);
     if (rv<0) {
       memset(userpass, 0, sizeof(userpass));
@@ -229,8 +226,7 @@ int AO_Provider__WrapRequest(AB_PROVIDER *pro,
 
 int AO_Provider__WrapMessage(AB_PROVIDER *pro,
                              AB_USER *u,
-			     GWEN_BUFFER *buf,
-			     uint32_t guiid) {
+			     GWEN_BUFFER *buf) {
   GWEN_BUFFER *tbuf;
   int rv;
 
@@ -246,7 +242,7 @@ int AO_Provider__WrapMessage(AB_PROVIDER *pro,
   }
   GWEN_Buffer_AppendString(tbuf, "<OFX>");
 
-  rv=AO_Provider__AddSignOn(pro, u, tbuf, guiid);
+  rv=AO_Provider__AddSignOn(pro, u, tbuf);
   if (rv<0) {
     DBG_ERROR(AQOFXCONNECT_LOGDOMAIN,
 	      "Error adding signon element (%d)", rv);
