@@ -30,27 +30,6 @@ GWEN_INHERIT(AB_USER, AO_USER);
 
 
 
-AO_USER_SERVERTYPE AO_User_ServerType_fromString(const char *s) {
-  assert(s);
-  if (strcasecmp(s, "http")==0)
-    return AO_User_ServerTypeHTTP;
-  else if (strcasecmp(s, "https")==0)
-    return AO_User_ServerTypeHTTPS;
-  return AO_User_ServerTypeUnknown;
-}
-
-
-
-const char *AO_User_ServerType_toString(AO_USER_SERVERTYPE t) {
-  switch(t) {
-  case AO_User_ServerTypeHTTP:  return "http";
-  case AO_User_ServerTypeHTTPS: return "https";
-  default:                      return "unknown";
-  }
-}
-
-
-
 uint32_t AO_User_Flags_fromDb(GWEN_DB_NODE *db, const char *name) {
   int i;
   uint32_t f=0;
@@ -130,74 +109,16 @@ void AO_User_Extend(AB_USER *u, AB_PROVIDER *pro,
     GWEN_INHERIT_SETDATA(AB_USER, AO_USER, u, ue, AO_User_FreeData);
 
     if (em==AB_ProviderExtendMode_Create) {
+      ue->httpVMajor=1;
+      ue->httpVMinor=0;
     }
     else {
-      const char *s;
-
-      ue->flags=AO_User_Flags_fromDb(db, "flags");
-
-      free(ue->brokerId);
-      s=GWEN_DB_GetCharValue(db, "brokerId", 0, NULL);
-      if (s)
-	ue->brokerId=strdup(s);
-      else
-	ue->brokerId=NULL;
-
-      free(ue->org);
-      s=GWEN_DB_GetCharValue(db, "org", 0, NULL);
-      if (s)
-	ue->org=strdup(s);
-      else
-	ue->org=NULL;
-
-      free(ue->fid);
-      s=GWEN_DB_GetCharValue(db, "fid", 0, NULL);
-      if (s)
-	ue->fid=strdup(s);
-      else
-	ue->fid=NULL;
-
-      s=GWEN_DB_GetCharValue(db, "serverType", 0, "https");
-      ue->serverType=AO_User_ServerType_fromString(s);
-
-      free(ue->serverAddr);
-      s=GWEN_DB_GetCharValue(db, "serverAddr", 0, NULL);
-      if (s)
-	ue->serverAddr=strdup(s);
-      else
-	ue->serverAddr=NULL;
-
-      ue->serverPort=GWEN_DB_GetIntValue(db, "serverPort", 0, 0);
-
-      free(ue->appId);
-      s=GWEN_DB_GetCharValue(db, "appId", 0, NULL);
-      if (s)
-	ue->appId=strdup(s);
-      else
-	ue->appId=NULL;
-
-      free(ue->appVer);
-      s=GWEN_DB_GetCharValue(db, "appVer", 0, NULL);
-      if (s)
-	ue->appVer=strdup(s);
-      else
-	ue->appVer=NULL;
-
-      free(ue->headerVer);
-      s=GWEN_DB_GetCharValue(db, "headerVer", 0, NULL);
-      if (s)
-	ue->headerVer=strdup(s);
-      else
-	ue->headerVer=NULL;
-
-      free(ue->clientUid);
-      s=GWEN_DB_GetCharValue(db, "clientUid", 0, NULL);
-      if (s)
-	ue->clientUid=strdup(s);
-      else
-	ue->clientUid=NULL;
+      AO_User_ReadDb(u, db);
     }
-
+  }
+  else if (em==AB_ProviderExtendMode_Reload) {
+    /* just reload user */
+    AO_User_ReadDb(u, db);
   }
   else {
     AO_USER *ue;
@@ -208,6 +129,10 @@ void AO_User_Extend(AB_USER *u, AB_PROVIDER *pro,
     if (em==AB_ProviderExtendMode_Save) {
       AO_User_Flags_toDb(db, "flags", ue->flags);
 
+      if (ue->bankName)
+	GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
+			     "bankName", ue->bankName);
+
       if (ue->brokerId)
 	GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
 			     "brokerId", ue->brokerId);
@@ -220,17 +145,10 @@ void AO_User_Extend(AB_USER *u, AB_PROVIDER *pro,
 	GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
 			     "fid", ue->fid);
 
-      GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
-			   "serverType",
-			   AO_User_ServerType_toString(ue->serverType));
-
       if (ue->serverAddr)
 	GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
 			     "serverAddr", ue->serverAddr);
 
-      GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
-                          "serverPort", ue->serverPort);
-
       if (ue->appId)
 	GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
 			     "appId", ue->appId);
@@ -245,6 +163,11 @@ void AO_User_Extend(AB_USER *u, AB_PROVIDER *pro,
       if (ue->clientUid)
 	GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
 			     "clientUid", ue->clientUid);
+
+      GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
+			  "httpVMajor", ue->httpVMajor);
+      GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
+			  "httpVMinor", ue->httpVMinor);
     }
   }
 }
@@ -256,6 +179,7 @@ void GWENHYWFAR_CB AO_User_FreeData(void *bp, void *p) {
 
   ue=(AO_USER*)p;
 
+  free(ue->bankName);
   free(ue->brokerId);
   free(ue->org);
   free(ue->fid);
@@ -270,6 +194,116 @@ void GWENHYWFAR_CB AO_User_FreeData(void *bp, void *p) {
 
 
 
+void AO_User_ReadDb(AB_USER *u, GWEN_DB_NODE *db) {
+  AO_USER *ue;
+  const char *s;
+
+  assert(u);
+  ue=GWEN_INHERIT_GETDATA(AB_USER, AO_USER, u);
+  assert(ue);
+
+  ue->flags=AO_User_Flags_fromDb(db, "flags");
+  
+  free(ue->bankName);
+  s=GWEN_DB_GetCharValue(db, "bankName", 0, NULL);
+  if (s)
+    ue->bankName=strdup(s);
+  else
+    ue->bankName=NULL;
+  
+  free(ue->brokerId);
+  s=GWEN_DB_GetCharValue(db, "brokerId", 0, NULL);
+  if (s)
+    ue->brokerId=strdup(s);
+  else
+    ue->brokerId=NULL;
+  
+  free(ue->org);
+  s=GWEN_DB_GetCharValue(db, "org", 0, NULL);
+  if (s)
+    ue->org=strdup(s);
+  else
+    ue->org=NULL;
+  
+  free(ue->fid);
+  s=GWEN_DB_GetCharValue(db, "fid", 0, NULL);
+  if (s)
+    ue->fid=strdup(s);
+  else
+    ue->fid=NULL;
+  
+  free(ue->serverAddr);
+  s=GWEN_DB_GetCharValue(db, "serverAddr", 0, NULL);
+  if (s)
+    ue->serverAddr=strdup(s);
+  else
+    ue->serverAddr=NULL;
+  
+  free(ue->appId);
+  s=GWEN_DB_GetCharValue(db, "appId", 0, NULL);
+  if (s)
+    ue->appId=strdup(s);
+  else
+    ue->appId=NULL;
+  
+  free(ue->appVer);
+  s=GWEN_DB_GetCharValue(db, "appVer", 0, NULL);
+  if (s)
+    ue->appVer=strdup(s);
+  else
+    ue->appVer=NULL;
+  
+  free(ue->headerVer);
+  s=GWEN_DB_GetCharValue(db, "headerVer", 0, NULL);
+  if (s)
+    ue->headerVer=strdup(s);
+  else
+    ue->headerVer=NULL;
+  
+  free(ue->clientUid);
+  s=GWEN_DB_GetCharValue(db, "clientUid", 0, NULL);
+  if (s)
+    ue->clientUid=strdup(s);
+  else
+    ue->clientUid=NULL;
+  
+  ue->httpVMajor=GWEN_DB_GetIntValue(db, "httpVMajor", 0, -1);
+  ue->httpVMinor=GWEN_DB_GetIntValue(db, "httpVMinor", 0, -1);
+  if (ue->httpVMajor==-1 || ue->httpVMinor==-1) {
+    ue->httpVMajor=1;
+    ue->httpVMinor=0;
+  }
+}
+
+
+
+const char *AO_User_GetBankName(const AB_USER *u) {
+  AO_USER *ue;
+
+  assert(u);
+  ue=GWEN_INHERIT_GETDATA(AB_USER, AO_USER, u);
+  assert(ue);
+
+  return ue->bankName;
+}
+
+
+
+void AO_User_SetBankName(AB_USER *u, const char *s) {
+  AO_USER *ue;
+
+  assert(u);
+  ue=GWEN_INHERIT_GETDATA(AB_USER, AO_USER, u);
+  assert(ue);
+
+  free(ue->bankName);
+  if (s) ue->bankName=strdup(s);
+  else ue->bankName=NULL;
+}
+
+
+
+
 const char *AO_User_GetBrokerId(const AB_USER *u) {
   AO_USER *ue;
 
@@ -349,30 +383,6 @@ void AO_User_SetFid(AB_USER *u, const char *s) {
 
 
 
-AO_USER_SERVERTYPE AO_User_GetServerType(const AB_USER *u) {
-  AO_USER *ue;
-
-  assert(u);
-  ue=GWEN_INHERIT_GETDATA(AB_USER, AO_USER, u);
-  assert(ue);
-
-  return ue->serverType;
-}
-
-
-
-void AO_User_SetServerType(AB_USER *u, AO_USER_SERVERTYPE t) {
-  AO_USER *ue;
-
-  assert(u);
-  ue=GWEN_INHERIT_GETDATA(AB_USER, AO_USER, u);
-  assert(ue);
-
-  ue->serverType=t;
-}
-
-
-
 const char *AO_User_GetServerAddr(const AB_USER *u) {
   AO_USER *ue;
 
@@ -399,30 +409,6 @@ void AO_User_SetServerAddr(AB_USER *u, const char *s) {
 
 
 
-int AO_User_GetServerPort(const AB_USER *u) {
-  AO_USER *ue;
-
-  assert(u);
-  ue=GWEN_INHERIT_GETDATA(AB_USER, AO_USER, u);
-  assert(ue);
-
-  return ue->serverPort;
-}
-
-
-
-void AO_User_SetServerPort(AB_USER *u, int i) {
-  AO_USER *ue;
-
-  assert(u);
-  ue=GWEN_INHERIT_GETDATA(AB_USER, AO_USER, u);
-  assert(ue);
-
-  ue->serverPort=i;
-}
-
-
-
 uint32_t AO_User_GetFlags(const AB_USER *u) {
   AO_USER *ue;
 
@@ -571,6 +557,54 @@ void AO_User_SetClientUid(AB_USER *u, const char *s) {
 
 
 
+int AO_User_GetHttpVMajor(const AB_USER *u) {
+  AO_USER *ue;
+
+  assert(u);
+  ue=GWEN_INHERIT_GETDATA(AB_USER, AO_USER, u);
+  assert(ue);
+
+  return ue->httpVMajor;
+}
+
+
+
+void AO_User_SetHttpVMajor(AB_USER *u, int i) {
+  AO_USER *ue;
+
+  assert(u);
+  ue=GWEN_INHERIT_GETDATA(AB_USER, AO_USER, u);
+  assert(ue);
+
+  ue->httpVMajor=i;
+}
+
+
+
+int AO_User_GetHttpVMinor(const AB_USER *u) {
+  AO_USER *ue;
+
+  assert(u);
+  ue=GWEN_INHERIT_GETDATA(AB_USER, AO_USER, u);
+  assert(ue);
+
+  return ue->httpVMinor;
+}
+
+
+
+void AO_User_SetHttpVMinor(AB_USER *u, int i) {
+  AO_USER *ue;
+
+  assert(u);
+  ue=GWEN_INHERIT_GETDATA(AB_USER, AO_USER, u);
+  assert(ue);
+
+  ue->httpVMinor=i;
+}
+
+
+
 
 
 
