@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id$
     begin       : Mon Mar 01 2004
-    copyright   : (C) 2004 by Martin Preuss
+    copyright   : (C) 2004-2010 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -20,20 +17,23 @@ typedef struct AO_USER AO_USER;
 struct AO_USER {
   uint32_t flags;
 
+  char *bankName;
   char *brokerId;
   char *org;
   char *fid;
-  AO_USER_SERVERTYPE serverType;
   char *serverAddr;
-  int serverPort;
   char *appId;
   char *appVer;
   char *headerVer;
   char *clientUid;
+
+  int httpVMajor;
+  int httpVMinor;
 };
 
 static void GWENHYWFAR_CB AO_User_FreeData(void *bp, void *p);
 
+static void AO_User_ReadDb(AB_USER *u, GWEN_DB_NODE *db);
 
 
 #endif
