@@ -94,6 +94,17 @@ int main(int argc, char **argv) {
     "Automatically accept all valid TLS certificate",
     "Automatically accept all valid TLS certificate"
   },
+  {
+    GWEN_ARGS_FLAGS_HAS_ARGUMENT, /* flags */
+    GWEN_ArgsType_Char,           /* type */
+    "charset",                    /* name */
+    0,                            /* minnum */
+    1,                            /* maxnum */
+    0,                            /* short option */
+    "charset",                    /* long option */
+    "Specify the output character set",       /* short description */
+    "Specify the output character set"        /* long description */
+  },
   {
     GWEN_ARGS_FLAGS_HAS_ARGUMENT, /* flags */
     GWEN_ArgsType_Char,           /* type */
@@ -155,6 +166,8 @@ int main(int argc, char **argv) {
     GWEN_BUFFER *ubuf;
 
     ubuf=GWEN_Buffer_new(0, 1024, 0, 1);
+    GWEN_Buffer_AppendString(ubuf, I18N("This is version "));
+    GWEN_Buffer_AppendString(ubuf, AQHBCI_VERSION_STRING "\n");
     GWEN_Buffer_AppendString(ubuf,
                              I18N("Usage: "));
     GWEN_Buffer_AppendString(ubuf, argv[0]);
@@ -216,7 +229,7 @@ int main(int argc, char **argv) {
     GWEN_Buffer_AppendString(ubuf,
 			     I18N("   Issue a single debit note (data from command line)\n"));
 
-    GWEN_Buffer_AppendString(ubuf, " transfers\n");
+    GWEN_Buffer_AppendString(ubuf, " debitnotes\n");
     GWEN_Buffer_AppendString(ubuf,
 			     I18N("   Issue a number of debit notes (data from a file)\n"));
 
